Crate ockam[−][src]
Modules
| history |
Structs
| Address | A generic component address |
| Cancel | A message wraper type that allows users to cancel message receival |
| Changes | |
| Contact | Contact is an abstraction responsible for storing user’s public data (mainly - public keys).
It is designed to share users’ public keys in cryptographically verifiable way.
Public keys together with metadata are organised into verifiable events chain exactly like |
| Context | |
| CreateKeyChange | |
| CreateKeyChangeData | |
| Credential | A credential that can be presented |
| CredentialAttributeSchema | An attribute describes a statement that the issuer of a credential is signing about the subject of the credential. |
| CredentialFragment1 | The information needed to convert a CredentialFragment2 to a Credential |
| CredentialFragment2 | A partial credential that will be completed by the holder |
| CredentialHolder | Represents a holder of a credential |
| CredentialIssuer | Represents an issuer of a credential |
| CredentialOffer | A credential offer is how an issuer informs a potential holder that a credential is available to them |
| CredentialPresentation | Indicates how to present a credential |
| CredentialRequest | A request for a credential generated from a credential offer |
| CredentialSchema | A schema describes the data format of a credential. |
| CredentialVerifier | Methods for verifying presentations |
| Error | The type of errors returned by Ockam functions. |
| EventIdentifier | Unique |
| Executor | Ockam node and worker executor |
| KeyAttributes | Attributes that are used to identify key |
| Lease | A lease for managing secrets |
| Mailbox | A mailbox for encoded messages |
| PresentationManifest | A list of the accepted schemas, public keys, and required to be revealed attributes from a verifier |
| Profile | Profile is an abstraction responsible for keeping, verifying and modifying user’s data (mainly - public keys). It is used to create new keys, rotate and revoke them. Public keys together with metadata will be organised into events chain, corresponding secret keys will be saved into the given Vault implementation. Events chain and corresponding secret keys are what fully determines Profile. |
| ProfileChange | Individual change applied to profile. |
| ProfileChangeEvent |
|
| ProfileEventAttributeKey | Pre-defined keys in |
| ProfileIdentifier | |
| RotateKeyChange | |
| RotateKeyChangeData | |
| Route | A full route to a peer |
| Routed | A message wrapper that stores message route information |
| Signature | |
| TransportMessage | A generic transport message |
Enums
| CredentialAttribute | The attribute data that is signed by |
| CredentialAttributeType | The data type of an attribute’s value. |
| CredentialError | The error types that can occur when creating or verifying a credential. |
| NodeError | Failure states from a router command |
| NodeMessage | Messages sent from the Node to the Executor |
| NodeReply | Successful return values from a router command |
| OckamError | |
| ProfileChangeProof | Variants of proofs that are allowed on a |
| ProfileChangeType | Possible types of |
| RouterMessage | A command message for router implementations |
| SignatureType |
Constants
| SECRET_ID | The label to indicate the secretid attribute in a schema/credential |
Traits
| BigArray | |
| Message | A user defined message that can be serialised and deserialised |
| ProfileVault | |
| Worker | Base ockam worker trait. |
Functions
| start_node |
Type Definitions
| ContactsDb | Contacts Database |
| Encoded | Alias of the type used for encoded data. |
| NodeReplyResult | |
| OfferIdBytes | Alias for an array of 32 bytes. |
| ProfileEventAttributes | |
| ProofBytes | Alias for an array of 48 bytes. |
| PublicKeyBytes | Alias for an array of 96 bytes. |
| Result | The type returned by Ockam functions. |
| SigningKeyBytes | Alias for an array of 32 bytes. |
Attribute Macros
| async_worker | |
| node | Marks an async function to be run in an ockam node. |