OwnedMappedMutexGuard

Struct OwnedMappedMutexGuard 

pub struct OwnedMappedMutexGuard<T, U = T>
where T: ?Sized, U: ?Sized,
{ /* private fields */ }
A owned handle to a held Mutex that has had a function applied to it via OwnedMutexGuard::map.

This can be used to hold a subfield of the protected data.

Implementations

Source

impl<T, U> OwnedMappedMutexGuard<T, U>
where T: ?Sized, U: ?Sized,

pub fn map<S, F>( this: OwnedMappedMutexGuard<T, U>, f: F, ) -> OwnedMappedMutexGuard<T, S>
where F: FnOnce(&mut U) -> &mut S,

Makes a new OwnedMappedMutexGuard for a component of the locked data.

This operation cannot fail as the OwnedMappedMutexGuard passed in already locked the mutex.

This is an associated function that needs to be used as OwnedMappedMutexGuard::map(...). A method would interfere with methods of the same name on the contents of the locked data.

pub fn try_map<S, F>( this: OwnedMappedMutexGuard<T, U>, f: F, ) -> Result<OwnedMappedMutexGuard<T, S>, OwnedMappedMutexGuard<T, U>>
where F: FnOnce(&mut U) -> Option<&mut S>,

Attempts to make a new OwnedMappedMutexGuard for a component of the locked data. The original guard is returned if the closure returns None.

This operation cannot fail as the OwnedMutexGuard passed in already locked the mutex.

This is an associated function that needs to be used as OwnedMutexGuard::try_map(...). A method would interfere with methods of the same name on the contents of the locked data.