ErrorCode

Struct ErrorCode 

#[non_exhaustive]
pub struct ErrorCode { pub origin: Origin, pub kind: Kind, pub extra: i32, }
A set of abstract error codes describing an error. See the module-level documentation for details.

The fields of this struct are pub for matching, but you need to go through one of the constructor functions to create one of these (and not a literal), as it is a #[non_exhaustive] type (which may change in the future, since it’s unclear if this provides value).

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
origin: Origin

The Origin of this error.

kind: Kind

The Kind of this error.

extra: i32

An additional identifying numeric payload, or 0 if none is relevant.

For example, it would be reasonable for this field to hold:

  • HTTP status code
  • OS errno/GetLastError code
  • The exit status returned by a subprocess
  • A numeric error code from some other system
  • Et cetera.

But should generally not be used to hold non-identifying metadata, such as the date, device IDs, as that information should be stored on the payload itself.

Concretely: two ErrorCode with different extra values should identify types of errors.

Implementations

Source

impl ErrorCode

pub fn new(origin: Origin, kind: Kind) -> ErrorCode

Construct the ErrorCode for an error.

pub fn new_with_extra(origin: Origin, kind: Kind, extra: i32) -> ErrorCode

Construct the ErrorCode for an error which contains an additional numeric payload.

pub fn unknown() -> ErrorCode

Construct an error code with very little useful information

pub fn update_unknown( self, o: impl Into<Option<Origin>>, k: impl Into<Option<Kind>>, ) -> ErrorCode

Attach an origin and/or kind to the error, without risk of overwriting more precise information value.