Struct ockam::Routed[][src]

pub struct Routed<M> where
    M: Message
{ /* fields omitted */ }

A message wrapper that stores message route information

Workers can accept arbitrary message types, which may not contain information about their routes. However, the ockam worker & messaging system already keeps track of this information internally. This type exposes this information to the user, without requiring changes in the user message types.

Implementations

impl<M> Routed<M> where
    M: Message
[src]

pub fn new(inner: M, route: Route) -> Routed<M>[src]

Create a new Routed message wrapper

pub fn reply(&self) -> Route[src]

Return a copy of the full return route of the wrapped message

pub fn sender(&self) -> Address[src]

Get a copy of the message sender address

pub fn take(self) -> M[src]

Consume the message wrapper