pub struct TcpInletOptions { /* private fields */ }Expand description
Options for an Inlet
Implementations
Sourceimpl TcpInletOptions
impl TcpInletOptions
Sourcepub fn new() -> TcpInletOptions
pub fn new() -> TcpInletOptions
Default constructor without Incoming Access Control
Sourcepub fn set_skip_handshake(self, skip_handshake: bool) -> TcpInletOptions
pub fn set_skip_handshake(self, skip_handshake: bool) -> TcpInletOptions
Skip Portal handshake for lower latency, but also lower throughput
Sourcepub fn skip_handshake(self) -> TcpInletOptions
pub fn skip_handshake(self) -> TcpInletOptions
Skip Portal handshake for lower latency, but also lower throughput
Sourcepub fn set_enable_nagle(self, enable_nagle: bool) -> TcpInletOptions
pub fn set_enable_nagle(self, enable_nagle: bool) -> TcpInletOptions
Enable Nagle’s algorithm for potentially higher throughput, but higher latency
Sourcepub fn enable_nagle(self) -> TcpInletOptions
pub fn enable_nagle(self) -> TcpInletOptions
Enable Nagle’s algorithm for potentially higher throughput, but higher latency
Sourcepub fn paused(self) -> TcpInletOptions
pub fn paused(self) -> TcpInletOptions
Set TCP inlet to paused mode after start. No unpause call [TcpInlet::unpause]
Sourcepub fn with_tls_certificate_provider(
self,
tls_certificate: Arc<dyn TlsCertificateProvider>,
) -> TcpInletOptions
pub fn with_tls_certificate_provider( self, tls_certificate: Arc<dyn TlsCertificateProvider>, ) -> TcpInletOptions
Set TLS certificate provider. Whe omitted the inlet will be clear-text
Sourcepub fn with_incoming_access_control_impl(
self,
access_control: impl IncomingAccessControl,
) -> TcpInletOptions
pub fn with_incoming_access_control_impl( self, access_control: impl IncomingAccessControl, ) -> TcpInletOptions
Set Incoming Access Control
Sourcepub fn with_incoming_access_control(
self,
access_control: Arc<dyn IncomingAccessControl>,
) -> TcpInletOptions
pub fn with_incoming_access_control( self, access_control: Arc<dyn IncomingAccessControl>, ) -> TcpInletOptions
Set Incoming Access Control
Sourcepub fn with_outgoing_access_control_impl(
self,
access_control: impl OutgoingAccessControl,
) -> TcpInletOptions
pub fn with_outgoing_access_control_impl( self, access_control: impl OutgoingAccessControl, ) -> TcpInletOptions
Set Outgoing Access Control
Sourcepub fn with_outgoing_access_control(
self,
access_control: Arc<dyn OutgoingAccessControl>,
) -> TcpInletOptions
pub fn with_outgoing_access_control( self, access_control: Arc<dyn OutgoingAccessControl>, ) -> TcpInletOptions
Set Outgoing Access Control