pub struct UdpPuncture { /* private fields */ }Expand description
Individual puncture with a specified peer.
See Wikipedia and ‘Peer-to-Peer Communication Across Network Address Translators’.
UDP and NAT Hole Punching are unreliable protocols. Expect send and receive failures.
Implementations
Sourceimpl UdpPuncture
impl UdpPuncture
Sourcepub async fn wait_for_puncture(
&mut self,
timeout: Duration,
) -> Result<(), Error>
pub async fn wait_for_puncture( &mut self, timeout: Duration, ) -> Result<(), Error>
Wait until puncture succeeds to the peer or a timeout. In case it’s already open, will return on next pong message
TODO: PUNCTURE optimize to return immediately if the puncture is open
Sourcepub fn sender_address(&self) -> Address
pub fn sender_address(&self) -> Address
Address of the Sender Worker
Sourcepub fn stop(&self, ctx: &Context) -> Result<(), Error>
pub fn stop(&self, ctx: &Context) -> Result<(), Error>
Stop the receiver (which will shut down everything else as well)
Sourcepub fn flow_control_id(&self) -> &FlowControlId
pub fn flow_control_id(&self) -> &FlowControlId
Flow Control Id