SQLite rust migrations
Modules
- migration_
20231231100000_ node_ name_ identity_ attributes - This migration adds a node name column to the identity attributes table
- migration_
20240111100001_ add_ authority_ tables - This migration moves attributes from identity_attributes to the authority_member table for authority nodes
- migration_
20240111100002_ delete_ trust_ context - This migration updates policies to not rely on trust_context_id,
also introduces
node_nameand replicates policy for each existing node - migration_
20240212100000_ split_ policies - This migration moves policies attached to resource types from table “resource_policy” to “resource_type_policy”
- migration_
20240313100000_ remove_ orphan_ resources - This migration removes orphan resources
- migration_
20240503100000_ update_ policy_ expressions - This migration updates the policy expressions so that they start with an operator
- migration_
20250114100000_ members_ authority_ id - This migration adds an authority_id to the authority_members table to track the authority having members.